@@ -11,13 +11,11 @@
 #ifndef FINISHEDVIEWSTEP_H
 #define FINISHEDVIEWSTEP_H
 
-#include <QObject>
-
+#include "DllMacro.h"
 #include "utils/PluginFactory.h"
 #include "viewpages/ViewStep.h"
 
-#include "DllMacro.h"
-
+class Config;
 class FinishedPage;
 
 class PLUGINDLLEXPORT FinishedViewStep : public Calamares::ViewStep
@@ -25,16 +23,6 @@ class PLUGINDLLEXPORT FinishedViewStep : public Calamares::ViewStep
     Q_OBJECT
 
 public:
-    enum class RestartMode
-    {
-        Never = 0,  ///< @brief Don't show button, just exit
-        UserUnchecked,  ///< @brief Show button, starts unchecked
-        UserChecked,  ///< @brief Show button, starts checked
-        Always  ///< @brief Show button, can't change, checked
-    };
-    /// @brief Returns the config-name of the given restart-mode @p m
-    static QString modeName( RestartMode m );
-
     explicit FinishedViewStep( QObject* parent = nullptr );
     ~FinishedViewStep() override;
 
@@ -58,16 +46,9 @@ public slots:
     void onInstallationFailed( const QString& message, const QString& details );
 
 private:
+    Config* m_config;
     FinishedPage* m_widget;
-
-    /**
-     * @brief At the end of installation (when this step is activated),
-     *      send a desktop notification via DBus that the install is done.
-     */
-    void sendNotification();
-
-    bool installFailed;
-    bool m_notifyOnFinished;
+    bool m_installFailed;  // Track if onInstallationFailed() was called
 };
 
 CALAMARES_PLUGIN_FACTORY_DECLARATION( FinishedViewStepFactory )
