@@ -1,19 +1,10 @@
-/* === This file is part of Calamares - <https://github.com/calamares> ===
+/* === This file is part of Calamares - <https://calamares.io> ===
  *
- *   Copyright 2014-2016, Teo Mrnjavac <teo@kde.org>
+ *   SPDX-FileCopyrightText: 2014-2016 Teo Mrnjavac <teo@kde.org>
+ *   SPDX-License-Identifier: GPL-3.0-or-later
  *
- *   Calamares is free software: you can redistribute it and/or modify
- *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation, either version 3 of the License, or
- *   (at your option) any later version.
+ *   Calamares is Free Software: see the License-Identifier above.
  *
- *   Calamares is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- *   GNU General Public License for more details.
- *
- *   You should have received a copy of the GNU General Public License
- *   along with Calamares. If not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifndef PARTITIONSPLITTERWIDGET_H
@@ -57,10 +48,7 @@ public:
 
     void init( Device* dev, bool drawNestedPartitions );
 
-    void setSplitPartition( const QString& path,
-                            qint64 minSize,
-                            qint64 maxSize,
-                            qint64 preferredSize );
+    void setSplitPartition( const QString& path, qint64 minSize, qint64 maxSize, qint64 preferredSize );
 
     qint64 splitPartitionSize() const;
     qint64 newPartitionSize() const;
@@ -80,20 +68,15 @@ protected:
 private:
     void setupItems( const QVector< PartitionSplitterItem >& items );
 
-    void drawPartitions( QPainter* painter,
-                         const QRect& rect,
-                         const QVector< PartitionSplitterItem >& itemList );
-    void drawSection( QPainter* painter, const QRect& rect_, int x, int width,
-                      const PartitionSplitterItem& item );
-    void drawResizeHandle( QPainter* painter,
-                           const QRect& rect_,
-                           int x );
+    void drawPartitions( QPainter* painter, const QRect& rect, const QVector< PartitionSplitterItem >& itemList );
+    void drawSection( QPainter* painter, const QRect& rect_, int x, int width, const PartitionSplitterItem& item );
+    void drawResizeHandle( QPainter* painter, const QRect& rect_, int x );
 
     PartitionSplitterItem _findItem( QVector< PartitionSplitterItem >& items,
-                                     std::function< bool ( PartitionSplitterItem& ) > condition ) const;
+                                     std::function< bool( PartitionSplitterItem& ) > condition ) const;
 
     int _eachItem( QVector< PartitionSplitterItem >& items,
-                   std::function< bool ( PartitionSplitterItem& ) > operation ) const;
+                   std::function< bool( PartitionSplitterItem& ) > operation ) const;
 
     QPair< QVector< PartitionSplitterItem >, qreal >
     computeItemsVector( const QVector< PartitionSplitterItem >& originalItems ) const;
@@ -114,4 +97,4 @@ private:
     bool m_drawNestedPartitions;
 };
 
-#endif // PARTITIONSPLITTERWIDGET_H
+#endif  // PARTITIONSPLITTERWIDGET_H
